@@ -1,18 +1,10 @@
 from .._compat import basestring
-from ..adapters.mssql import (
-    MSSQL,
-    MSSQLN,
-    MSSQL3,
-    MSSQL4,
-    MSSQL3N,
-    MSSQL4N,
-    Vertica,
-    Sybase,
-)
+from ..adapters.mssql import (MSSQL, MSSQL3, MSSQL3N, MSSQL4, MSSQL4N, MSSQLN,
+                              Sybase, Vertica)
 from ..helpers.methods import varquote_aux
 from ..objects import Expression
-from .base import SQLDialect
 from . import dialects, sqltype_for
+from .base import SQLDialect
 
 
 @dialects.register_for(MSSQL)
@@ -136,7 +128,7 @@ class MSSQLDialect(SQLDialect):
         limitby=None,
         distinct=False,
         for_update=False,
-        with_cte=None  # ['recursive' | '', sql]
+        with_cte=None,  # ['recursive' | '', sql]
     ):
         dst, whr, grp, order, limit, upd = "", "", "", "", "", ""
         if distinct is True:
@@ -159,7 +151,7 @@ class MSSQLDialect(SQLDialect):
 
         if with_cte:
             recursive, cte = with_cte
-            recursive = ' RECURSIVE' if recursive else ''
+            recursive = " RECURSIVE" if recursive else ""
             with_cte = "WITH%s %s " % (recursive, cte)
         else:
             with_cte = ""
@@ -247,7 +239,7 @@ class MSSQLDialect(SQLDialect):
     def concat_add(self, tablename):
         return "; ALTER TABLE %s ADD " % tablename
 
-    def drop_index(self, name, table, if_exists = False):
+    def drop_index(self, name, table, if_exists=False):
         return "DROP INDEX %s ON %s;" % (self.quote(name), table._rname)
 
     def st_astext(self, first, query_env={}):
@@ -369,7 +361,7 @@ class MSSQL3Dialect(MSSQLDialect):
         limitby=None,
         distinct=False,
         for_update=False,
-        with_cte=None  # ['recursive' | '', sql]
+        with_cte=None,  # ['recursive' | '', sql]
     ):
         dst, whr, grp, order, limit, offset, upd = "", "", "", "", "", "", ""
         if distinct is True:
@@ -397,7 +389,7 @@ class MSSQL3Dialect(MSSQLDialect):
 
         if with_cte:
             recursive, cte = with_cte
-            recursive = ' RECURSIVE' if recursive else ''
+            recursive = " RECURSIVE" if recursive else ""
             with_cte = "WITH%s %s " % (recursive, cte)
         else:
             with_cte = ""
@@ -429,7 +421,7 @@ class MSSQL4Dialect(MSSQL3Dialect):
         limitby=None,
         distinct=False,
         for_update=False,
-        with_cte=None  # ['recursive' | '', sql]
+        with_cte=None,  # ['recursive' | '', sql]
     ):
         dst, whr, grp, order, limit, offset, upd = "", "", "", "", "", "", ""
         if distinct is True:
@@ -460,7 +452,7 @@ class MSSQL4Dialect(MSSQL3Dialect):
 
         if with_cte:
             recursive, cte = with_cte
-            recursive = ' RECURSIVE' if recursive else ''
+            recursive = " RECURSIVE" if recursive else ""
             with_cte = "WITH%s %s " % (recursive, cte)
         else:
             with_cte = ""
