@@ -315,7 +315,11 @@ class Migrator(object):
             query = "CREATE TABLE %s(\n    %s\n)%s" % (table_rname, fields, other)
 
         uri = self.adapter.uri
-        if uri.startswith("sqlite:///") or uri.startswith("spatialite:///"):
+        if isinstance(self, InDBMigrator):
+            # No filesystem path should be used when storing table details in database.
+            dbpath = ''
+            self.adapter.folder = ''
+        elif uri.startswith("sqlite:///") or uri.startswith("spatialite:///"):
             if PY2:
                 path_encoding = (
                     sys.getfilesystemencoding()
@@ -582,7 +586,7 @@ class Migrator(object):
         writelog = bool(logfilename)
         if writelog:
             isabs = os.path.isabs(logfilename)
-        if table and table._dbt and writelog and self.adapter.folder:
+        if table and table._dbt and writelog and (self.adapter.folder or isinstance(self, InDBMigrator)):
             if isabs:
                 table._loggername = logfilename
             else:
